Class: Aws::BackupGateway::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::BackupGateway::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-backupgateway/client.rb,
sig/client.rbs
Overview
An API client for BackupGateway. To construct a client, you need to configure a :region and :credentials.
client = Aws::BackupGateway::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateGatewayToServerResponseSuccess, _CreateGatewayResponseSuccess, _DeleteGatewayResponseSuccess, _DeleteHypervisorResponseSuccess, _DisassociateGatewayFromServerResponseSuccess, _GetBandwidthRateLimitScheduleResponseSuccess, _GetGatewayResponseSuccess, _GetHypervisorPropertyMappingsResponseSuccess, _GetHypervisorResponseSuccess, _GetVirtualMachineResponseSuccess, _ImportHypervisorConfigurationResponseSuccess, _ListGatewaysResponseSuccess, _ListHypervisorsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListVirtualMachinesResponseSuccess, _PutBandwidthRateLimitScheduleResponseSuccess, _PutHypervisorPropertyMappingsResponseSuccess, _PutMaintenanceStartTimeResponseSuccess, _StartVirtualMachinesMetadataSyncResponseSuccess, _TagResourceResponseSuccess, _TestHypervisorConfigurationResponseSuccess, _UntagResourceResponseSuccess, _UpdateGatewayInformationResponseSuccess, _UpdateGatewaySoftwareNowResponseSuccess, _UpdateHypervisorResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_gateway_to_server(params = {}) ⇒ Types::AssociateGatewayToServerOutput
Associates a backup gateway with your server.
-
#create_gateway(params = {}) ⇒ Types::CreateGatewayOutput
Creates a backup gateway.
-
#delete_gateway(params = {}) ⇒ Types::DeleteGatewayOutput
Deletes a backup gateway.
-
#delete_hypervisor(params = {}) ⇒ Types::DeleteHypervisorOutput
Deletes a hypervisor.
-
#disassociate_gateway_from_server(params = {}) ⇒ Types::DisassociateGatewayFromServerOutput
Disassociates a backup gateway from the specified server.
-
#get_bandwidth_rate_limit_schedule(params = {}) ⇒ Types::GetBandwidthRateLimitScheduleOutput
Retrieves the bandwidth rate limit schedule for a specified gateway.
-
#get_gateway(params = {}) ⇒ Types::GetGatewayOutput
By providing the ARN (Amazon Resource Name), this API returns the gateway.
-
#get_hypervisor(params = {}) ⇒ Types::GetHypervisorOutput
This action requests information about the specified hypervisor to which the gateway will connect.
-
#get_hypervisor_property_mappings(params = {}) ⇒ Types::GetHypervisorPropertyMappingsOutput
This action retrieves the property mappings for the specified hypervisor.
-
#get_virtual_machine(params = {}) ⇒ Types::GetVirtualMachineOutput
By providing the ARN (Amazon Resource Name), this API returns the virtual machine.
-
#import_hypervisor_configuration(params = {}) ⇒ Types::ImportHypervisorConfigurationOutput
Connect to a hypervisor by importing its configuration.
-
#list_gateways(params = {}) ⇒ Types::ListGatewaysOutput
Lists backup gateways owned by an Amazon Web Services account in an Amazon Web Services Region.
-
#list_hypervisors(params = {}) ⇒ Types::ListHypervisorsOutput
Lists your hypervisors.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the tags applied to the resource identified by its Amazon Resource Name (ARN).
-
#list_virtual_machines(params = {}) ⇒ Types::ListVirtualMachinesOutput
Lists your virtual machines.
-
#put_bandwidth_rate_limit_schedule(params = {}) ⇒ Types::PutBandwidthRateLimitScheduleOutput
This action sets the bandwidth rate limit schedule for a specified gateway.
-
#put_hypervisor_property_mappings(params = {}) ⇒ Types::PutHypervisorPropertyMappingsOutput
This action sets the property mappings for the specified hypervisor.
-
#put_maintenance_start_time(params = {}) ⇒ Types::PutMaintenanceStartTimeOutput
Set the maintenance start time for a gateway.
-
#start_virtual_machines_metadata_sync(params = {}) ⇒ Types::StartVirtualMachinesMetadataSyncOutput
This action sends a request to sync metadata across the specified virtual machines.
-
#tag_resource(params = {}) ⇒ Types::TagResourceOutput
Tag the resource.
-
#test_hypervisor_configuration(params = {}) ⇒ Struct
Tests your hypervisor configuration to validate that backup gateway can connect with the hypervisor and its resources.
-
#untag_resource(params = {}) ⇒ Types::UntagResourceOutput
Removes tags from the resource.
-
#update_gateway_information(params = {}) ⇒ Types::UpdateGatewayInformationOutput
Updates a gateway's name.
-
#update_gateway_software_now(params = {}) ⇒ Types::UpdateGatewaySoftwareNowOutput
Updates the gateway virtual machine (VM) software.
-
#update_hypervisor(params = {}) ⇒ Types::UpdateHypervisorOutput
Updates a hypervisor metadata, including its host, username, and password.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-backupgateway/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1518 1519 1520 |
# File 'lib/aws-sdk-backupgateway/client.rb', line 1518 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1521 1522 1523 |
# File 'lib/aws-sdk-backupgateway/client.rb', line 1521 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_gateway_to_server(params = {}) ⇒ Types::AssociateGatewayToServerOutput
Associates a backup gateway with your server. After you complete the association process, you can back up and restore your VMs through the gateway.
87 |
# File 'sig/client.rbs', line 87
def associate_gateway_to_server: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 |
# File 'lib/aws-sdk-backupgateway/client.rb', line 1491 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::BackupGateway') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-backupgateway' context[:gem_version] = '1.55.0' Seahorse::Client::Request.new(handlers, context) end |
#create_gateway(params = {}) ⇒ Types::CreateGatewayOutput
Creates a backup gateway. After you create a gateway, you can
associate it with a server using the AssociateGatewayToServer
operation.
98 |
# File 'sig/client.rbs', line 98
def create_gateway: (
|
#delete_gateway(params = {}) ⇒ Types::DeleteGatewayOutput
Deletes a backup gateway.
116 |
# File 'sig/client.rbs', line 116
def delete_gateway: (
|
#delete_hypervisor(params = {}) ⇒ Types::DeleteHypervisorOutput
Deletes a hypervisor.
126 |
# File 'sig/client.rbs', line 126
def delete_hypervisor: (
|
#disassociate_gateway_from_server(params = {}) ⇒ Types::DisassociateGatewayFromServerOutput
Disassociates a backup gateway from the specified server. After the disassociation process finishes, the gateway can no longer access the virtual machines on the server.
136 |
# File 'sig/client.rbs', line 136
def disassociate_gateway_from_server: (
|
#get_bandwidth_rate_limit_schedule(params = {}) ⇒ Types::GetBandwidthRateLimitScheduleOutput
Retrieves the bandwidth rate limit schedule for a specified gateway. By default, gateways do not have bandwidth rate limit schedules, which means no bandwidth rate limiting is in effect. Use this to get a gateway's bandwidth rate limit schedule.
147 |
# File 'sig/client.rbs', line 147
def get_bandwidth_rate_limit_schedule: (
|
#get_gateway(params = {}) ⇒ Types::GetGatewayOutput
By providing the ARN (Amazon Resource Name), this API returns the gateway.
157 |
# File 'sig/client.rbs', line 157
def get_gateway: (
|
#get_hypervisor(params = {}) ⇒ Types::GetHypervisorOutput
This action requests information about the specified hypervisor to which the gateway will connect. A hypervisor is hardware, software, or firmware that creates and manages virtual machines, and allocates resources to them.
167 |
# File 'sig/client.rbs', line 167
def get_hypervisor: (
|
#get_hypervisor_property_mappings(params = {}) ⇒ Types::GetHypervisorPropertyMappingsOutput
This action retrieves the property mappings for the specified hypervisor. A hypervisor property mapping displays the relationship of entity properties available from the hypervisor to the properties available in Amazon Web Services.
179 |
# File 'sig/client.rbs', line 179
def get_hypervisor_property_mappings: (
|
#get_virtual_machine(params = {}) ⇒ Types::GetVirtualMachineOutput
By providing the ARN (Amazon Resource Name), this API returns the virtual machine.
189 |
# File 'sig/client.rbs', line 189
def get_virtual_machine: (
|
#import_hypervisor_configuration(params = {}) ⇒ Types::ImportHypervisorConfigurationOutput
Connect to a hypervisor by importing its configuration.
199 |
# File 'sig/client.rbs', line 199
def import_hypervisor_configuration: (
|
#list_gateways(params = {}) ⇒ Types::ListGatewaysOutput
Lists backup gateways owned by an Amazon Web Services account in an Amazon Web Services Region. The returned list is ordered by gateway Amazon Resource Name (ARN).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
220 |
# File 'sig/client.rbs', line 220
def list_gateways: (
|
#list_hypervisors(params = {}) ⇒ Types::ListHypervisorsOutput
Lists your hypervisors.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
232 |
# File 'sig/client.rbs', line 232
def list_hypervisors: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists the tags applied to the resource identified by its Amazon Resource Name (ARN).
244 |
# File 'sig/client.rbs', line 244
def list_tags_for_resource: (
|
#list_virtual_machines(params = {}) ⇒ Types::ListVirtualMachinesOutput
Lists your virtual machines.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
255 |
# File 'sig/client.rbs', line 255
def list_virtual_machines: (
|
#put_bandwidth_rate_limit_schedule(params = {}) ⇒ Types::PutBandwidthRateLimitScheduleOutput
This action sets the bandwidth rate limit schedule for a specified gateway. By default, gateways do not have a bandwidth rate limit schedule, which means no bandwidth rate limiting is in effect. Use this to initiate a gateway's bandwidth rate limit schedule.
267 |
# File 'sig/client.rbs', line 267
def put_bandwidth_rate_limit_schedule: (
|
#put_hypervisor_property_mappings(params = {}) ⇒ Types::PutHypervisorPropertyMappingsOutput
This action sets the property mappings for the specified hypervisor. A hypervisor property mapping displays the relationship of entity properties available from the hypervisor to the properties available in Amazon Web Services.
287 |
# File 'sig/client.rbs', line 287
def put_hypervisor_property_mappings: (
|
#put_maintenance_start_time(params = {}) ⇒ Types::PutMaintenanceStartTimeOutput
Set the maintenance start time for a gateway.
306 |
# File 'sig/client.rbs', line 306
def put_maintenance_start_time: (
|
#start_virtual_machines_metadata_sync(params = {}) ⇒ Types::StartVirtualMachinesMetadataSyncOutput
This action sends a request to sync metadata across the specified virtual machines.
320 |
# File 'sig/client.rbs', line 320
def start_virtual_machines_metadata_sync: (
|
#tag_resource(params = {}) ⇒ Types::TagResourceOutput
Tag the resource.
330 |
# File 'sig/client.rbs', line 330
def tag_resource: (
|
#test_hypervisor_configuration(params = {}) ⇒ Struct
Tests your hypervisor configuration to validate that backup gateway can connect with the hypervisor and its resources.
345 |
# File 'sig/client.rbs', line 345
def test_hypervisor_configuration: (
|
#untag_resource(params = {}) ⇒ Types::UntagResourceOutput
Removes tags from the resource.
358 |
# File 'sig/client.rbs', line 358
def untag_resource: (
|
#update_gateway_information(params = {}) ⇒ Types::UpdateGatewayInformationOutput
Updates a gateway's name. Specify which gateway to update using the Amazon Resource Name (ARN) of the gateway in your request.
369 |
# File 'sig/client.rbs', line 369
def update_gateway_information: (
|
#update_gateway_software_now(params = {}) ⇒ Types::UpdateGatewaySoftwareNowOutput
Updates the gateway virtual machine (VM) software. The request immediately triggers the software update.
200 OK success response
immediately. However, it might take some time for the update to
complete.
380 |
# File 'sig/client.rbs', line 380
def update_gateway_software_now: (
|
#update_hypervisor(params = {}) ⇒ Types::UpdateHypervisorOutput
Updates a hypervisor metadata, including its host, username, and password. Specify which hypervisor to update using the Amazon Resource Name (ARN) of the hypervisor in your request.
390 |
# File 'sig/client.rbs', line 390
def update_hypervisor: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1511 1512 1513 |
# File 'lib/aws-sdk-backupgateway/client.rb', line 1511 def waiter_names [] end |