Class: Aws::BackupGateway::Types::UpdateHypervisorInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::BackupGateway::Types::UpdateHypervisorInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backupgateway/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:username, :password]
Instance Attribute Summary collapse
-
#host ⇒ String
The updated host of the hypervisor.
-
#hypervisor_arn ⇒ String
The Amazon Resource Name (ARN) of the hypervisor to update.
-
#log_group_arn ⇒ String
The Amazon Resource Name (ARN) of the group of gateways within the requested log.
-
#name ⇒ String
The updated name for the hypervisor.
-
#password ⇒ String
The updated password for the hypervisor.
-
#username ⇒ String
The updated username for the hypervisor.
Instance Attribute Details
#host ⇒ String
The updated host of the hypervisor. This can be either an IP address or a fully-qualified domain name (FQDN).
1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 |
# File 'lib/aws-sdk-backupgateway/types.rb', line 1257 class UpdateHypervisorInput < Struct.new( :hypervisor_arn, :host, :username, :password, :name, :log_group_arn) SENSITIVE = [:username, :password] include Aws::Structure end |
#hypervisor_arn ⇒ String
The Amazon Resource Name (ARN) of the hypervisor to update.
1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 |
# File 'lib/aws-sdk-backupgateway/types.rb', line 1257 class UpdateHypervisorInput < Struct.new( :hypervisor_arn, :host, :username, :password, :name, :log_group_arn) SENSITIVE = [:username, :password] include Aws::Structure end |
#log_group_arn ⇒ String
The Amazon Resource Name (ARN) of the group of gateways within the requested log.
1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 |
# File 'lib/aws-sdk-backupgateway/types.rb', line 1257 class UpdateHypervisorInput < Struct.new( :hypervisor_arn, :host, :username, :password, :name, :log_group_arn) SENSITIVE = [:username, :password] include Aws::Structure end |
#name ⇒ String
The updated name for the hypervisor
1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 |
# File 'lib/aws-sdk-backupgateway/types.rb', line 1257 class UpdateHypervisorInput < Struct.new( :hypervisor_arn, :host, :username, :password, :name, :log_group_arn) SENSITIVE = [:username, :password] include Aws::Structure end |
#password ⇒ String
The updated password for the hypervisor.
1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 |
# File 'lib/aws-sdk-backupgateway/types.rb', line 1257 class UpdateHypervisorInput < Struct.new( :hypervisor_arn, :host, :username, :password, :name, :log_group_arn) SENSITIVE = [:username, :password] include Aws::Structure end |
#username ⇒ String
The updated username for the hypervisor.
1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 |
# File 'lib/aws-sdk-backupgateway/types.rb', line 1257 class UpdateHypervisorInput < Struct.new( :hypervisor_arn, :host, :username, :password, :name, :log_group_arn) SENSITIVE = [:username, :password] include Aws::Structure end |